@@ -102,10 +102,10 @@ class BaseHandler(RequestHandler):
                     parameter_type = parameter.annotation
                     # 形参类型为空，尝试获取形参默认值类型
                     if parameter_type is inspect.Parameter.empty:
-                        if parameter.default is inspect.Parameter.empty:
-                            parameter_type = type(parameter.default)
-                        else:
-                            parameter_type = type(parameter.default)
+                        # if parameter.default is inspect.Parameter.empty:
+                        #     parameter_type = type(parameter.default)
+                        # else:
+                        parameter_type = type(parameter.default)
                     # # 获取实参类型
                     # argument_type = type(argument_value)
                     if isinstance(argument_value, list):  # 如果参数是集合类型要进行遍历并进行转码
@@ -114,7 +114,8 @@ class BaseHandler(RequestHandler):
                             params_list.append(parse_val(argument_value[0], parameter_type))
                         else:  # 多个要使用集合存入
                             params_list.append([parse_val(v, parameter_type) for v in argument_value])
-
+                    else:
+                        params_list.append(parse_val(argument_value, parameter_type))
             # 判断是否为异步非阻塞方法，true 则直接调用
             if inspect.iscoroutinefunction(handler_method):
                 data = await handler_method(*params_list)
